Challenges and Perspectives
---------------------------

This page complements our manuscript
`Bergen et al. (MSB, 2021) RNA velocity - Current challenges and future perspectives <https://doi.org/10.15252/msb.202110282>`_

We provide several examples to discuss potential pitfalls of current RNA velocity
modeling approaches, and provide guidance on how the ensuing challenges may be addressed.
Our aspiration is to suggest promising future directions and to stimulate a communities effort on further model extensions.

In the following, you find two vignettes with several use cases, as well as an in-depth analysis of time-dependent kinetic rate parameters.

Potential pitfalls
^^^^^^^^^^^^^^^^^^
.. image:: https://user-images.githubusercontent.com/31883718/115840357-e354f480-a41b-11eb-8a95-12f7564fd9b0.png
   :width: 300px
   :align: left

This notebook reproduces Fig. 2 with several use cases, including multiple kinetics in Dentate Gyrus,
transcriptional boost in erythroid lineage, and misleading arrow projections in mature PBMCs.

Notebook: `Perspectives <Perspectives>`_

|
Kinetic parameter analysis
^^^^^^^^^^^^^^^^^^^^^^^^^^
.. image:: https://user-images.githubusercontent.com/31883718/130656606-00bd44be-9071-4008-be1b-244fa9c2d244.png
   :width: 300px
   :align: left

This notebook reproduces Fig. 3, where we demonstrate how time-variable kinetic rates
shape the curvature patterns of gene activation.

Notebook: `Kinetic parameter analysis <Perspectives_parameters>`_
